"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Schema = void 0;
const SnowflakeSchema_1 = require("@sudobot/types/SnowflakeSchema");
const zod_1 = require("zod");
exports.Schema = zod_1.z
    .object({
    enabled: zod_1.z.boolean().default(false).describe("Whether or not URLFish is enabled"),
    channels: zod_1.z
        .object({
        enabled_in: zod_1.z.array(SnowflakeSchema_1.zSnowflake).describe("Channels to enable URLFish in")
    })
        .or(zod_1.z.object({
        disabled_in: zod_1.z.array(SnowflakeSchema_1.zSnowflake).describe("Channels to disable URLFish in")
    }))
        .optional()
        .describe("Channels to enable or disable URLFish in"),
    log_channel: SnowflakeSchema_1.zSnowflake.optional().describe("Channel to log URLFish events to"),
    action: zod_1.z
        .enum(["delete", "warn", "mute", "kick", "ban"])
        .default("delete")
        .describe("Action to take when a phishing URL is detected"),
    mute_duration: zod_1.z
        .number()
        .positive()
        .min(1000)
        .optional()
        .describe("Duration to mute a user for when a phishing URL is detected"),
    infraction_reason: zod_1.z.string().optional().describe("Reason to use when creating an infraction")
})
    .describe("URLFish Configuration")
    .optional();
